@@ -12,7 +12,7 @@ from itertools import count
 from .connection import maybe_channel, is_connection
 from .entity import Exchange, Queue, DELIVERY_MODES
 from .compression import compress
-from .serialization import encode, registry
+from .serialization import encode, prepare_accept_content
 from .utils import ChannelPromise, maybe_list
 
 __all__ = ['Exchange', 'Queue', 'Producer', 'Consumer']
@@ -347,13 +347,7 @@ class Consumer(object):
             self.auto_declare = auto_declare
         if on_decode_error is not None:
             self.on_decode_error = on_decode_error
-        self.accept = accept
-
-        if self.accept is not None:
-            self.accept = set(
-                n if '/' in n else registry.name_to_type[n]
-                for n in self.accept
-            )
+        self.accept = prepare_accept_content(accept)
 
         if self.channel:
             self.revive(self.channel)
@@ -575,13 +569,13 @@ class Consumer(object):
 
     def _receive_callback(self, message):
         accept = self.accept
-        if accept is not None:
-            message.accept = accept
         on_m, channel, decoded = self.on_message, self.channel, None
         try:
             m2p = getattr(channel, 'message_to_python', None)
             if m2p:
                 message = m2p(message)
+            if accept is not None:
+                message.accept = accept
             decoded = None if on_m else message.decode()
         except Exception, exc:
             if not self.on_decode_error:
