@@ -221,7 +221,7 @@ def retry_over_time(fun, catch, args=[], kwargs={}, errback=None,
             if callback:
                 callback()
             tts = (errback(exc, interval_range, retries) if errback
-                   else next(interval_range))
+                   else interval_range.next())
             if tts:
                 for i in range(int(tts / interval_step)):
                     if callback:
