@@ -33,6 +33,23 @@ except NameError:
                 raise
             return args[0]
 
+############## socket.error.errno ############################################
+
+
+def get_errno(exc):
+    """:exc:`socket.error` and :exc:`IOError` first got
+    the ``.errno`` attribute in Py2.7"""
+    try:
+        return exc.errno
+    except AttributeError:
+        try:
+            # e.args = (errno, reason)
+            if isinstance(exc.args, tuple) and len(exc.args) == 2:
+                return exc.args[0]
+        except AttributeError:
+            pass
+    return 0
+
 ############## collections.OrderedDict #######################################
 try:
     from collections import OrderedDict
