@@ -4,13 +4,10 @@ kombu.utils.limits
 
 Token bucket implementation for rate limiting.
 
-:copyright: (c) 2009 - 2012 by Ask Solem.
-:license: BSD, see LICENSE for more details.
-
 """
 import time
 
-__all__ = ["TokenBucket"]
+__all__ = ['TokenBucket']
 
 
 class TokenBucket(object):
